
<p align="center" id='大礼包-banner'>
    <a target="_blank" href='http://python4office.cn/fuli/fuli-source-0726/'>
    <img src="https://banner-1300615378.cos.ap-guangzhou.myqcloud.com/%E6%A8%AA%E6%9D%A1/Python%E5%A4%A7%E7%A4%BC%E5%8C%85.jpg" width="100%"/>
    </a>   
</p>



<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>


<p align="center" name="'github">
  	<a href="https://mp.weixin.qq.com/s/yaSmFKO3RrBpyanW3nvRAQ">
	<img src="https://img.shields.io/badge/QQ-163434413-orange"/>
  </a>
    	<a href="https://mp.weixin.qq.com/s/NN2pX2bQPpczOeGF4ARNtw">
	<img src="https://img.shields.io/badge/%E5%BE%AE%E4%BF%A1-%E4%BA%A4%E6%B5%81%E7%BE%A4-brightgreen"/>
  </a>
</p>


-------------------------------------------------------------------------------


## 📚简介


poocr 是快速调用腾讯云AI平台功能的接口合集。

``poocr``所有功能的实现，都依托于腾讯云的文字识别，如果是小白用户，可以**扫码下图，免费开通**~

![](https://article-1300615378.cos.ap-nanjing.myqcloud.com/potencent%2Fapi-doc%2Fshare.jpg)

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ poocr -U
```


-------------------------------------------------------------------------------

## 📝功能

- [📘Python自动化办公的官网：https://www.python-office.com/](https://www.python-office.com/)

-  💻所有功能的列表👉[点我直达](https://www.python-office.com/video/poocr.html)


## 常见问题

1. 如何配置poocr-config.toml？

第一步，你需要开通腾讯云的发票识别功能（收费功能，很便宜）：[点我直达](https://cloud.tencent.com/act/cps/redirect?redirect=10098&cps_key=ca76be5a2293ba3906d6d5407aea15ee)

第二步，你需要设置一个子账户（不花钱）：[点我直达](https://cloud.tencent.com/act/cps/redirect?redirect=36394&cps_key=ca76be5a2293ba3906d6d5407aea15ee)

如果以上配置，自己不懂技术，难以实现的话，可以付费找我帮你配置。我的微信，点击直达👉[CoderWanFeng](http://python4office.cn/wechat-qrcode/)，99元/次，一次就够了。我有自己的工作，都是打工人，拒绝白嫖哈，多谢理解。
## 🏗️添砖加瓦


### 📐PR的建议

poocr欢迎任何人来添砖加瓦，贡献代码，建议提交的pr（pull request）符合一些规范，规范如下：

### 🧬贡献代码的步骤

1. 在Gitee或者Github上fork项目到自己的repo
2. 把fork过去的项目也就是你的项目clone到你的本地
3. 修改代码
4. commit后push到自己的库
5. 登录Gitee或Github在你首页可以看到一个 pull request 按钮，点击它，填写一些说明信息，然后提交到master分支即可。
6. 等待维护者合并


### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和python-office代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/pobaidu/issues)

-------------------------------------------------------------------------------


## 📌联系作者


<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>
